==> Munoh-linux-x64-v1.3.0.zip: Munoh-linux-x64-v1.3.0/resources/app/ghost/neko/talk/default.js <==
var TALK = [
  {type: "normal", talk: [[0, "ねむい(´・ω・`)"]]},
  {type: "normal", talk: [[0, "にゃー"]]},
  {type: "normal", talk: [[0, "わん"]]},
  {type: "normal", talk: [[0, "ゴロゴロ"]]},
  {type: "normal", talk: [[0, "うんちでた"]]},
  {type: "normal", talk: [[0, "飲みいこ？"]]},
  {type: "normal", talk: [[0, "おそら きれい"]]},
  {type: "normal", talk: [[0, "おなかすいた"]]},
  {type: "normal", talk: [[0, "Zzz . . .", "sleep"]]},
  {type: "normal", talk: [[0, "ねこちゃんです"]]},
  {type: "normal", talk: [[0, "♪"]]},
  {type: "normal", talk: [[0, "おふとんいく"], [500, "Zzz . . .", "sleep"]]},
  // {type: "normal", talk: [[0, "おはよー"]]},
  {type: "normal", talk: [[0, "りんご"],
                          [300, "ごりら"],
                          [300, "らっぱ"],
                          [400, "ぱいなっぷる"],
                          [500, "…"],
                          [3000, "るーびっくきゅーぶ"],
                          [400, "……"],
                          [1000, "ぶたどん！"],
                          [600, "(´・ω・`)", "sleep"]]},
  {type: "normal", talk: [[0, "九九言えるよ！"],
                          [200, "しち いち が しち"],
                          [200, "しち に じゅうし"],
                          [200, "しち さん にじゅういち"],
                          [200, "しち し にじゅうはち"],
                          [200, "しち ご さんじゅうご"],
                          [200, "しち ろく しじゅうに"],
                          [200, "しち しち"],
                          [500, "…"],
                          [3000, "しち しち"],
                          [400, "……"],
                          [1000, "しち は ごじゅうろく"],
                          [200, "しち く ろくじゅうさん！"]]},
  {type: "normal", talk: [[0, "実は俺、Electronでできてるんだぜ…", "alt"]]},
  {type: "normal", talk: [[0, "名張って虫多くね？"]]},
  {type: "normal", talk: [[0, "よていはみてい"]]},
  {type: "normal", talk: [[0, "そう、物理的には、ね"]]},
  {type: "normal", talk: [[0, "地震"], [300, "かみなり", "reverse"], [300, "火事"], [300, '留年(´・ω・`)', "reverse"]]},
];

var GREET = [
  {type: "normal", talk: [[0, "おはようございました"]]},
  {type: "normal", talk: [[0, "おはよー"]]},
  {type: "normal", talk: [[0, "とりあえずビールで"]]},
];

function GINPUT(str) {
  switch (true) {
  case /^おはよ.*/.test(str):
    return "おはよー";
  case /^(時間|じかん|時刻|じこく|time)$/.test(str):
    var d = new Date();
    return "今は" + d.getHours() + "時" + d.getMinutes() + "分だよ！" ;
  }
  return false;
}

==> Munoh-linux-x64-v1.4.0.zip: Munoh-linux-x64-v1.4.0/resources/app/ghost/neko/talk/default.js <==
var TALK = [
  {type: "normal", talk: [[0, "ねむい(´・ω・`)"]]},
  {type: "normal", talk: [[0, "にゃー"]]},
  {type: "normal", talk: [[0, "わん"]]},
  {type: "normal", talk: [[0, "ゴロゴロ"]]},
  {type: "normal", talk: [[0, "うんちでた"]]},
  {type: "normal", talk: [[0, "%username%、飲みいこ？"]]},
  {type: "normal", talk: [[0, "おそら きれい"]]},
  {type: "normal", talk: [[0, "おなかすいた"]]},
  {type: "normal", talk: [[0, "Zzz . . .", "sleep"]]},
  {type: "normal", talk: [[0, "ねこちゃんです"]]},
  {type: "normal", talk: [[0, "♪"]]},
  {type: "normal", talk: [[0, "おふとんいく"], [500, "Zzz . . .", "sleep"]]},
  // {type: "normal", talk: [[0, "おはよー"]]},
  {type: "normal", talk: [[0, "りんご"],
                          [300, "ごりら"],
                          [300, "らっぱ"],
                          [400, "ぱいなっぷる"],
                          [500, "…"],
                          [3000, "るーびっくきゅーぶ"],
                          [400, "……"],
                          [1000, "ぶたどん！"],
                          [600, "(´・ω・`)", "sleep"]]},
  {type: "normal", talk: [[0, "九九言えるよ！"],
                          [200, "しち いち が しち"],
                          [200, "しち に じゅうし"],
                          [200, "しち さん にじゅういち"],
                          [200, "しち し にじゅうはち"],
                          [200, "しち ご さんじゅうご"],
                          [200, "しち ろく しじゅうに"],
                          [200, "しち しち"],
                          [500, "…"],
                          [3000, "しち しち"],
                          [400, "……"],
                          [1000, "しち は ごじゅうろく"],
                          [200, "しち く ろくじゅうさん！"]]},
  {type: "normal", talk: [[0, "実は俺、Electronでできてるんだぜ…", "alt"]]},
  {type: "normal", talk: [[0, "名張って虫多くね？"]]},
  {type: "normal", talk: [[0, "よていはみてい"]]},
  {type: "normal", talk: [[0, "そう、物理的には、ね"]]},
  {type: "normal", talk: [[0, "地震"], [300, "かみなり", "reverse"], [300, "火事"], [300, '留年(´・ω・`)', "reverse"]]},
];

var GREET = [
  {type: "normal", talk: [[0, "おはようございました"]]},
  {type: "normal", talk: [[0, "%username%、おはよー"]]},
  {type: "normal", talk: [[0, "とりあえずビールで"]]},
];


var GINPUT = function(str) {
  switch (true) {
  case /^おはよ.*/.test(str):
    return "%username%、おはよー";
  case /^(時間|じかん|時刻|じこく|time)$/.test(str):
    var d = new Date();
    return "今は" + d.getHours() + "時" + d.getMinutes() + "分だよ！" ;
  }
  return false;
};

module.exports = {TALK, GREET, GINPUT};
